# Cisco 2G/3G/4G wireless connection

This package contains the two plugins. The check plugin **_cisco_cellular_lte_** and the inventory plugin **_inv_cisco_cellular_lte_**.

<details><summary>cisco_cellular_lte</summary>

This check plugin will monitor 2G/3G/4G wireless connections. By default it will only discover cellular interfaces with a SIM card attached. It will show

-    the connection status
-    the values for RSSI, RSRP and RSRQ
-    the Bandwith used in/out
-    the wireless band used


and in the deails
-    the associated IP-Addresses (IPv4 and IPv6)
-    the roaming state
-    the current channel
-    the network code
-    the service typoe
-    the provider time
-    modem state and status
-    the APN
-    the configured and the current APN type

</details>
<details><summary>inv_cisco_cellular_lte</summary>

This inventory plugin adds under _Networking_ -> _Cellular (LTE)_:

-    IMEI (International Mobile Equipment Identifier)
-    IMSI (International Mobile Subscriber Identifier)
-    ICCID (Integrated Circuit Card ID)
-    MSISDN (Mobile Subscriber Integrated Services Digital Network Number)
-    FSN (Factory Serial Number)
-    Network code
-    Country
-    APN (Access Point Nam)
-    Service type
-    current band

With the inventory view _Search Cellular (LTE)_ you can filter and report on this data for all your hosts.
</details>

---
### Download
* [cisco_cellular_lte.mkp](https://thl-cmk.hopto.org/gitlab/checkmk/cisco/cisco_cellular_lte/-/raw/master/cisco_cellular_lte.mkp "Download the MKP file")
                        
---
### Installation

You can install the package by uploading it to your CheckMK site and as site user run `mkp install cisco_cellular_lte.mkp`.


In the Enterprise/Free edition of CheckMK you can use the GUI to install the package (_Setup_ -> _Extension Packages_ -> _Upload package_)

---
### Want to Contribute?
Nice ;-) Have a look at the [contribution guidelines](CONTRIBUTING.md "Contributing")

---
### Check Info

The plugin creates the service **_Cellular_** for each discovered cellular interface with the **_cellular_interface_name_** as item

<details><summary>Montoring states</summary>

| State | condition | WATO | 
| ------ | ------ | ------ |
| WARN | no SIM card attached to the interface | yes |
| CRIT | connection state not active | yes |
| CRIT | modem state not up | yes |
| CRIT | modem not online | yes |
| WARN | connection is roaming | yes |
| WARN/CRIT | RSSI is below -75dBm/-85dBm | yes |
| WARN/CRIT | RSRP is below -100dBm/-115dBm| yes |
| WARN/CRIT | RSRQ is below -8dB/-15dB | yes |
| WARN | current Band is not as expected | yes |

</details>

<details><summary>Perfdata</summary>

| Metric | Unit | Perfometer |
| ------ | ------ | ------ |
| Input Bandwidth | bit/s | yes |
| Output bandwidt | bit/s | yes |
| RSSI | dBm | no |
| RSRQ | dB | no |
| RSRP | dBm | no |

</details>

---
### WATO
<details><summary>Service monitoring rule</summary>

| Section | Rule name |
| ------ | ------ |
| Networking | Cisco cellular LTE  |

| Option | Defailt value |
| ------ | ------ |
| Lower levels for RSRP | -100dBm/-115dBm |
| Lower levels for RSRQ | -8dB/-15dB |
| Lower levels for RSSI | -75 dBm/-85dBm |
| Expected Band | LTE Band |
| Monitoring state if current band is not expected band | WARN |
| Monitoring state if the device is roaming | WARN |
| Monitoring state if no SIM card associated | WARN |
| Monitoring state if the device is not connected | WARN |
| Monitoring state if the modem is not up | WARN |
| Monitoring state if the modem is not online | WARN |
| the device is not affected by Cisco Bug ID CSCvt55347 | disabled |

</details> 

<details><summary>Discovery rule</summary>

| Section | Rule name |
| ------ | ------ |
| Discovery of individual services | Cisco cellular LTE  |

| Option | Defailt value |
| ------ | ------ |
| Discover interfaces without associated SIM card | disabled |

</details> 

<details><summary>HW/SW inventory rules</summary>
The inventory plugin is not configurable.
</details> 

---
### Sample Output

Sample output

![sample output](/doc/sample.jpg?raw=true "sample output")

Sample output details

![sample output details](/doc/sample-details.jpg?raw=true "sample output details")

